@@ -33,7 +33,7 @@ anova_immer <- function( object , ... ){
     dfr$p <- NA
     dfr[1,"Chisq"] <- dfr[1,"Deviance"] - dfr[2,"Deviance"]
     dfr[1,"df"] <- abs( dfr[1,"Npars"] - dfr[2,"Npars"] )
-    dfr[ 1, "p" ] <- round( 1 - pchisq( dfr[1,"Chisq"] , df= dfr[1,"df"] ) , 5 )
+    dfr[ 1, "p" ] <- round( 1 - stats::pchisq( dfr[1,"Chisq"] , df= dfr[1,"df"] ) , 5 )
     for ( vv in 2:( ncol(dfr))){ dfr[,vv] <- round( dfr[,vv] , 5 ) }
     print( dfr )
     invisible(dfr)
@@ -42,4 +42,5 @@ anova_immer <- function( object , ... ){
 
 anova.immer_cml <- anova_immer
 # anova.immer_HRM <- IRT.anova.immer_HRM
-anova.immer_HRM <- anova_immer
\ No newline at end of file
+anova.immer_HRM <- anova_immer
+anova.lc2_agreement <- anova_immer
\ No newline at end of file
