@@ -2,9 +2,9 @@
 #####################################
 # sampling from a truncated normal distribution
 rtrnorm <- function( N , mean , sd , lower = rep(-Inf,N) , upper=rep(Inf,N) ){
-	t1 <- pnorm( lower , mean = mean , sd = sd )
-	t2 <- pnorm( upper , mean = mean , sd = sd )
-	rn <- runif( N , t1 , t2 )
-	qnorm( rn , mean = mean , sd = sd )
+	t1 <- stats::pnorm( lower , mean = mean , sd = sd )
+	t2 <- stats::pnorm( upper , mean = mean , sd = sd )
+	rn <- stats::runif( N , t1 , t2 )
+	stats::qnorm( rn , mean = mean , sd = sd )
 				}
 #########################################				
\ No newline at end of file
