@@ -4,7 +4,7 @@
 
 # on attach immer
 .onAttach <- function(libname,pkgname){
-  d <- packageDescription("immer")
+  d <- utils::packageDescription("immer")
   d1 <- d$Version
   packageStartupMessage(
 		paste("" ,d$Package," " , d1 ," (",d$Date,")",sep="")  )
@@ -13,7 +13,7 @@
 	
 version <- function(pkg="immer"){
   lib <- dirname(system.file(package = pkg))
-  d <- packageDescription(pkg)
+  d <- utils::packageDescription(pkg)
   return(paste(d$Package,d$Version,d$Date,lib))
 }
 
